@@ -1,7 +1,7 @@
 /*
- * Switches.java Copyright (C) 2019. Daniel H. Huson
+ * Switches.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,5 @@ package jloda;
  * Daniel Huson, 6.2019
  */
 public class Switches {
-    public static final boolean Install4JLaunchBug = true;
     public static final boolean notificationInSwingBug = true;
 }
