@@ -1,7 +1,7 @@
 /*
- * SplittableTabPane.java Copyright (C) 2019. Daniel H. Huson
+ * SplittableTabPane.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.fx.control;
@@ -38,6 +39,7 @@ import javafx.scene.layout.Pane;
 import javafx.scene.layout.StackPane;
 import javafx.stage.Stage;
 import jloda.util.Basic;
+import jloda.util.ProgramProperties;
 
 import java.io.Closeable;
 import java.io.IOException;
@@ -54,9 +56,9 @@ public class SplittableTabPane extends Pane {
     private final ObjectProperty<TabPane> focusedTabPane = new SimpleObjectProperty<>();
     private final ASingleSelectionModel<Tab> selectionModel = new ASingleSelectionModel<>();
 
-    private ObservableList<Tab> tabs = FXCollections.observableArrayList();
+    private final ObservableList<Tab> tabs = FXCollections.observableArrayList();
 
-    private ObservableMap<TabPane, SplitPane> tabPane2ParentSplitPane = FXCollections.observableHashMap();
+    private final ObservableMap<TabPane, SplitPane> tabPane2ParentSplitPane = FXCollections.observableHashMap();
 
     private static final String TAB_DRAG_KEY = "tab";
     private final ObjectProperty<Tab> draggingTab = new SimpleObjectProperty<>();
@@ -440,17 +442,13 @@ public class SplittableTabPane extends Pane {
             menuItems.add(closeAll);
 
             tab.setClosable(true);
-            tab.setOnCloseRequest((e) -> {
-                close.getOnAction().handle(null);
-            });
+            tab.setOnCloseRequest((e) -> close.getOnAction().handle(null));
             menuItems.add(new SeparatorMenuItem());
         }
 
         if (isAllowUndock()) {
             final MenuItem redock = new MenuItem("Redock");
-            redock.setOnAction((e) -> {
-                moveTab(tab, null, getFocusedTabPane());
-            });
+            redock.setOnAction((e) -> moveTab(tab, null, getFocusedTabPane()));
             // we don't show the redock menu item because the undocked window doesn't have a tab
 
             final MenuItem undock = new MenuItem("Undock");
@@ -492,9 +490,7 @@ public class SplittableTabPane extends Pane {
         menuItems.add(new SeparatorMenuItem());
 
         final MenuItem changeSplitOrientation = new MenuItem("Change Split Orientation");
-        changeSplitOrientation.setOnAction((e) -> {
-            splitPane.setOrientation(splitPane.getOrientation() == Orientation.VERTICAL ? Orientation.HORIZONTAL : Orientation.VERTICAL);
-        });
+        changeSplitOrientation.setOnAction((e) -> splitPane.setOrientation(splitPane.getOrientation() == Orientation.VERTICAL ? Orientation.HORIZONTAL : Orientation.VERTICAL));
         menuItems.add(changeSplitOrientation);
 
         final ArrayList<MenuItem> existingItems;
@@ -663,6 +659,7 @@ public class SplittableTabPane extends Pane {
             stage.setTitle(((Labeled) tab.getGraphic()).getText());
         else
             stage.setTitle("Untitled");
+        stage.getIcons().addAll(ProgramProperties.getProgramIconsFX());
 
         stage.setScene(new Scene(root, width, height));
         stage.sizeToScene();
@@ -671,7 +668,7 @@ public class SplittableTabPane extends Pane {
         return new AuxiliaryWindow(stage, tab);
     }
 
-    private class AuxiliaryWindow {
+    private static class AuxiliaryWindow {
         final private Stage stage;
         final private Tab tab;
 
