@@ -1,7 +1,7 @@
 /*
- * SearchManager.java Copyright (C) 2019. Daniel H. Huson
+ * SearchManager.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.fx.find;
@@ -78,7 +79,7 @@ public class SearchManager {
         replaceText.addListener(c -> message.set(""));
 
         searcherProperty().addListener((c, o, n) -> {
-            if (n instanceof ITextSearcher)
+            if (n instanceof ITextSearcher || n instanceof TableViewSearcher)
                 service.setExecutor(Platform::runLater); // must run text searchers in JavaFX application thread
             else if (n instanceof IObjectSearcher) // run other searchers in external thread
                 service.setExecutor(ProgramExecutorService.getInstance());
