@@ -1,7 +1,7 @@
 /*
- * CircleShape.java Copyright (C) 2019. Daniel H. Huson
+ * CircleShape.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.fx.shapes;
@@ -41,11 +42,11 @@ public class CircleShape extends Circle implements ISized {
 
     @Override
     public double getWidth() {
-        return 2 * getRadius();
+        return 2.0 * getRadius();
     }
 
     @Override
     public double getHeight() {
-        return 2 * getRadius();
+        return 2.0 * getRadius();
     }
 }
