@@ -1,7 +1,7 @@
 /*
- * QuasiMedianNetwork.java Copyright (C) 2019. Daniel H. Huson
+ * QuasiMedianNetwork.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.progs;
@@ -105,8 +106,7 @@ public class QuasiMedianNetwork {
             for (int i = 0; i < weights.length; i++)
                 weights[i] = Double.parseDouble(st.nextToken());
         } else
-            for (int i = 0; i < weights.length; i++)
-                weights[i] = 1;
+            Arrays.fill(weights, 1);
 
         Set outputSequences;
 
@@ -153,16 +153,14 @@ public class QuasiMedianNetwork {
      * @return quasi median closure
      */
     public static Set<String> computeQuasiMedianClosure(Set<String> sequences, String refA, String refB) {
-        Set<String> oldSequences = new TreeSet<>();
-        Set<String> curSequences = new HashSet<>();
         Set<String> newSequences = new HashSet<>();
 
         System.err.println("Computing quasi-median closure:");
-        oldSequences.addAll(sequences);
-        curSequences.addAll(sequences);
+        Set<String> oldSequences = new TreeSet<>(sequences);
+        Set<String> curSequences = new HashSet<>(sequences);
 
         while (curSequences.size() > 0) {
-            String[] oldArray = oldSequences.toArray(new String[oldSequences.size()]);
+            String[] oldArray = oldSequences.toArray(new String[0]);
             newSequences.clear();
             for (String seqA : oldArray) {
                 for (String seqB : oldArray) {
@@ -202,7 +200,7 @@ public class QuasiMedianNetwork {
 
         System.err.println("Computing geodesically-pruned quasi-median closure:");
 
-        String[] input = (String[]) sequences.toArray(new String[sequences.size()]);
+        String[] input = (String[]) sequences.toArray(new String[0]);
 
         double[][] scores = computeScores(input, sequenceLength);
 
@@ -257,23 +255,23 @@ public class QuasiMedianNetwork {
                 result.addAll(geodesic);
 
 
-                    System.err.println("------Sequences :");
-                    System.err.println(input[i]);
-                    System.err.println(input[j]);
-                    for (int x = 0; x < sequenceLength; x++)
-                        System.err.print(use.get(x) ? "x" : " ");
-                    System.err.println();
-                    System.err.println("Refs:");
+                System.err.println("------Sequences :");
+                System.err.println(input[i]);
+                System.err.println(input[j]);
+                for (int x = 0; x < sequenceLength; x++)
+                    System.err.print(use.get(x) ? "x" : " ");
+                System.err.println();
+                System.err.println("Refs:");
 
-                    System.err.println(refA);
-                    System.err.println(refB);
-                    System.err.println("Compressed (" + compressed.size() + "):");
+                System.err.println(refA);
+                System.err.println(refB);
+                System.err.println("Compressed (" + compressed.size() + "):");
                 for (String aCompressed : compressed) System.err.println(aCompressed);
-                    System.err.println("Closure (" + closure.size() + "):");
+                System.err.println("Closure (" + closure.size() + "):");
                 for (Object aClosure : closure) System.err.println(aClosure);
-                    System.err.println("Expanded (" + expanded.size() + "):");
+                System.err.println("Expanded (" + expanded.size() + "):");
                 for (Object anExpanded : expanded) System.err.println(anExpanded);
-                    System.err.println("Geodesic (" + geodesic.size() + "):");
+                System.err.println("Geodesic (" + geodesic.size() + "):");
                 for (Object aGeodesic : geodesic) System.err.println(aGeodesic);
 
             }
@@ -469,7 +467,7 @@ public class QuasiMedianNetwork {
                 stack.add(third);
             }
         }
-        return (String[]) median.toArray(new String[median.size()]);
+        return (String[]) median.toArray(new String[0]);
     }
 
     /**
@@ -520,7 +518,7 @@ public class QuasiMedianNetwork {
                 }
             }
         }
-        return (String[]) median.toArray(new String[median.size()]);
+        return (String[]) median.toArray(new String[0]);
     }
 
     /**
@@ -644,8 +642,7 @@ public class QuasiMedianNetwork {
      * @return sequences present in the median joining network
      */
     private static Set<String> computeMedianJoiningMainLoop(Set<String> input, double[] weights, int epsilon) {
-        Set<String> sequences = new HashSet<>();
-        sequences.addAll(input);
+        Set<String> sequences = new HashSet<>(input);
 
         boolean changed = true;
         while (changed) {
@@ -658,7 +655,7 @@ public class QuasiMedianNetwork {
                 changed = true;   // sequences have been changed, recompute graph
             } else {
                 // determine min connection cost:
-                double minConnectionCost = Double.MAX_VALUE;
+                double minConnectionCost = Double.POSITIVE_INFINITY;
 
                 for (Node u = graph.getFirstNode(); u != null; u = u.getNext()) {
                     String seqU = (String) u.getInfo();
@@ -721,7 +718,7 @@ public class QuasiMedianNetwork {
      * @param feasibleLinks
      */
     private static void computeMinimumSpanningNetwork(Set sequences, double[] weights, int epsilon, PhyloSplitsGraph graph, EdgeSet feasibleLinks) {
-        String[] array = (String[]) sequences.toArray(new String[sequences.size()]);
+        String[] array = (String[]) sequences.toArray(new String[0]);
         // compute a distance matrix between all sequences:
         double[][] matrix = new double[array.length][array.length];
 
@@ -731,11 +728,7 @@ public class QuasiMedianNetwork {
             for (int j = i + 1; j < array.length; j++) {
                 matrix[i][j] = computeDistance(array[i], array[j], weights);
                 Double value = matrix[i][j];
-                List<Pair<Integer, Integer>> pairs = value2pairs.get(value);
-                if (pairs == null) {
-                    pairs = new LinkedList<>();
-                    value2pairs.put(value, pairs);
-                }
+                List<Pair<Integer, Integer>> pairs = value2pairs.computeIfAbsent(value, k -> new LinkedList<>());
                 pairs.add(new Pair<>(i, j));
             }
         }
@@ -753,7 +746,7 @@ public class QuasiMedianNetwork {
         }
         int numComponentsMSN = array.length;
 
-        double maxValue = Double.MAX_VALUE;
+        double maxValue = Double.POSITIVE_INFINITY;
 
         // consider each set of pairs of taxa for a given edge length, in ascending order of edge lengths
         for (Double value : value2pairs.keySet()) {
@@ -800,7 +793,7 @@ public class QuasiMedianNetwork {
                             componentsOfMSN[k] = componentsOfMSN[i];
                 }
             }
-            if (numComponentsMSN == 1 && maxValue == Double.MAX_VALUE)
+            if (numComponentsMSN == 1 && maxValue == Double.POSITIVE_INFINITY)
                 maxValue = threshold + epsilon; // once network is connected, add all edges upto threshold+epsilon
         }
     }
