@@ -1,7 +1,7 @@
 /*
- * Gif89Frame.java Copyright (C) 2019. Daniel H. Huson
+ * Gif89Frame.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 //******************************************************************************
@@ -208,7 +209,7 @@ public abstract class Gif89Frame {
         int transflag = itransparent == -1 ? 0 : 1;
         if (transflag == 1 || epluribus)   // using transparency or animating ?
         {
-            os.write((int) '!');             // GIF Extension Introducer
+            os.write('!');             // GIF Extension Introducer
             os.write(0xf9);                  // Graphic Control Label
             os.write(4);                     // subsequent data block size
             os.write((disposalCode << 2) | transflag); // packed fields (1 byte)
@@ -221,7 +222,7 @@ public abstract class Gif89Frame {
     //----------------------------------------------------------------------------
 
     private void writeImageDescriptor(OutputStream os) throws IOException {
-        os.write((int) ',');                // Image Separator
+        os.write(',');                // Image Separator
         Put.leShort(thePosition.x, os);
         Put.leShort(thePosition.y, os);
         Put.leShort(theWidth, os);
