@@ -1,7 +1,7 @@
 /*
- * SearchManager.java Copyright (C) 2019. Daniel H. Huson
+ * SearchManager.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.swing.find;
@@ -226,17 +227,11 @@ public class SearchManager implements IDirectableViewer {
         } else {
             findDialog.clearMessage();
             if (worker == null || !worker.isAlive()) {
-                worker = new Thread(new Runnable() {
-                    public void run() {
-                        notifyLockUserInput();
-                        final boolean found = doFindAndReplace(new ProgressDialog("Search", "Find and replace", searcher.getParent()));
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run() {
-                                findDialog.setMessage(found ? "Replaced" : "No replacements");
-                            }
-                        });
-                        notifyUnlockUserInput();
-                    }
+                worker = new Thread(() -> {
+                    notifyLockUserInput();
+                    final boolean found = doFindAndReplace(new ProgressDialog("Search", "Find and replace", searcher.getParent()));
+                    SwingUtilities.invokeLater(() -> findDialog.setMessage(found ? "Replaced" : "No replacements"));
+                    notifyUnlockUserInput();
                 });
                 worker.setPriority(Thread.currentThread().getPriority() - 1);
                 worker.start();
@@ -262,7 +257,7 @@ public class SearchManager implements IDirectableViewer {
                 final String regexp = prepareRegularExpression(equateUnderscoreWithSpace ? searchText.replaceAll("_", " ") : searchText);
                 final Pattern pattern = Pattern.compile(regexp);
 
-                try {
+                try (progressListener) {
                     while (ok) {
                         if (isGlobalScope() || oSearcher.isCurrentSelected()) {
                             String label = oSearcher.getCurrentLabel();
@@ -285,8 +280,6 @@ public class SearchManager implements IDirectableViewer {
                     }
                 } catch (CanceledException e) {
                     System.err.println("Search canceled");
-                } finally {
-                    progressListener.close();
                 }
             } else if (searcher instanceof ITextSearcher) {
                 ITextSearcher tSearcher = (ITextSearcher) searcher;
@@ -322,18 +315,12 @@ public class SearchManager implements IDirectableViewer {
         } else {
             findDialog.clearMessage();
             if (worker == null || !worker.isAlive()) {
-                worker = new Thread(new Runnable() {
-                    public void run() {
-                        notifyLockUserInput();
-                        final boolean found = doFindFirst();
+                worker = new Thread(() -> {
+                    notifyLockUserInput();
+                    final boolean found = doFindFirst();
 
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run() {
-                                findDialog.setMessage(found ? "Found" : "No matches");
-                            }
-                        });
-                        notifyUnlockUserInput();
-                    }
+                    SwingUtilities.invokeLater(() -> findDialog.setMessage(found ? "Found" : "No matches"));
+                    notifyUnlockUserInput();
                 });
                 worker.setPriority(Thread.currentThread().getPriority() - 1);
                 worker.start();
@@ -406,18 +393,12 @@ public class SearchManager implements IDirectableViewer {
         } else {
             findDialog.clearMessage();
             if (worker == null || !worker.isAlive()) {
-                worker = new Thread(new Runnable() {
-                    public void run() {
-                        notifyLockUserInput();
-                        final boolean found = doFindNext(new ProgressDialog("Search", "Find next", searcher.getParent()));
+                worker = new Thread(() -> {
+                    notifyLockUserInput();
+                    final boolean found = doFindNext(new ProgressDialog("Search", "Find next", searcher.getParent()));
 
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run() {
-                                findDialog.setMessage(found ? "Found" : "No matches");
-                            }
-                        });
-                        notifyUnlockUserInput();
-                    }
+                    SwingUtilities.invokeLater(() -> findDialog.setMessage(found ? "Found" : "No matches"));
+                    notifyUnlockUserInput();
                 });
                 worker.setPriority(Thread.currentThread().getPriority() - 1);
                 worker.start();
@@ -439,7 +420,7 @@ public class SearchManager implements IDirectableViewer {
 
                 final String regexp = prepareRegularExpression(equateUnderscoreWithSpace ? searchText.replaceAll("_", " ") : searchText);
                 final Pattern pattern = Pattern.compile(regexp);
-                try {
+                try (progressListener) {
                     while (ok) {
                         if (isGlobalScope() || oSearcher.isCurrentSelected()) {
                             String label = oSearcher.getCurrentLabel();
@@ -458,8 +439,6 @@ public class SearchManager implements IDirectableViewer {
                     }
                 } catch (CanceledException e) {
                     System.err.println("Search canceled");
-                } finally {
-                    progressListener.close();
                 }
             } else if (searcher instanceof ITextSearcher) {
                 ITextSearcher tSearcher = (ITextSearcher) searcher;
@@ -490,22 +469,16 @@ public class SearchManager implements IDirectableViewer {
         } else {
             findDialog.clearMessage();
             if (worker == null || !worker.isAlive()) {
-                worker = new Thread(new Runnable() {
-                    public void run() {
-                        notifyLockUserInput();
-                        ProgressListener progressListener = new ProgressDialog("Search", "Find all", searcher.getParent());
-                        int found = doFindAll(progressListener);
-                        if (found == Integer.MIN_VALUE)
-                            found = 0;
-                        final int finalFound = Math.abs(found);
-                        progressListener.close();
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run() {
-                                findDialog.setMessage("Found: " + finalFound);
-                            }
-                        });
-                        notifyUnlockUserInput();
-                    }
+                worker = new Thread(() -> {
+                    notifyLockUserInput();
+                    ProgressListener progressListener = new ProgressDialog("Search", "Find all", searcher.getParent());
+                    int found = doFindAll(progressListener);
+                    if (found == Integer.MIN_VALUE)
+                        found = 0;
+                    final int finalFound = Math.abs(found);
+                    progressListener.close();
+                    SwingUtilities.invokeLater(() -> findDialog.setMessage("Found: " + finalFound));
+                    notifyUnlockUserInput();
                 });
                 worker.setPriority(Thread.currentThread().getPriority() - 1);
                 worker.start();
@@ -604,44 +577,38 @@ public class SearchManager implements IDirectableViewer {
         } else {
             findDialog.clearMessage();
             if (worker == null || !worker.isAlive()) {
-                worker = new Thread(new Runnable() {
-                    public void run() {
-                        notifyLockUserInput();
-                        int count = 0;
+                worker = new Thread(() -> {
+                    notifyLockUserInput();
+                    int count = 0;
 
-                        try {
+                    try {
 
-                            if (file != null && file.exists()) {
-                                BufferedReader r = new BufferedReader(new FileReader(file));
+                        if (file != null && file.exists()) {
+                            BufferedReader r = new BufferedReader(new FileReader(file));
 
-                                ProgressListener progressListener = new ProgressDialog("Search", "Find all", searcher.getParent());
-                                String aLine;
-                                while ((aLine = r.readLine()) != null) {
-                                    aLine = aLine.trim();
-                                    if (aLine.length() > 0 && !aLine.startsWith("#")) {
-                                        System.err.println("find and select: " + aLine);
-                                        setSearchText(aLine);
-                                        int found = doFindAll(progressListener);
-                                        boolean canceled = (found < 0);
-                                        if (found != Integer.MIN_VALUE)
-                                            count += Math.abs(found);
-                                        if (canceled)
-                                            break;
-                                    }
+                            ProgressListener progressListener = new ProgressDialog("Search", "Find all", searcher.getParent());
+                            String aLine;
+                            while ((aLine = r.readLine()) != null) {
+                                aLine = aLine.trim();
+                                if (aLine.length() > 0 && !aLine.startsWith("#")) {
+                                    System.err.println("find and select: " + aLine);
+                                    setSearchText(aLine);
+                                    int found = doFindAll(progressListener);
+                                    boolean canceled = (found < 0);
+                                    if (found != Integer.MIN_VALUE)
+                                        count += Math.abs(found);
+                                    if (canceled)
+                                        break;
                                 }
-                                progressListener.close();
                             }
-                        } catch (Exception ex) {
-                            Basic.caught(ex);
+                            progressListener.close();
                         }
-                        final int finalCount = Math.abs(count);
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run() {
-                                new Message(findDialog.getFrame(), "Matches: " + finalCount, 150, 100);
-                            }
-                        });
-                        notifyUnlockUserInput();
+                    } catch (Exception ex) {
+                        Basic.caught(ex);
                     }
+                    final int finalCount = Math.abs(count);
+                    SwingUtilities.invokeLater(() -> new Message(findDialog.getFrame(), "Matches: " + finalCount, 150, 100));
+                    notifyUnlockUserInput();
                 });
                 worker.setPriority(Thread.currentThread().getPriority() - 1);
                 worker.start();
@@ -659,17 +626,11 @@ public class SearchManager implements IDirectableViewer {
         } else {
             findDialog.clearMessage();
             if (worker == null || !worker.isAlive()) {
-                worker = new Thread(new Runnable() {
-                    public void run() {
-                        notifyLockUserInput();
-                        final int found = doReplaceAll();
-                        SwingUtilities.invokeLater(new Runnable() {
-                            public void run() {
-                                findDialog.setMessage("Replacements: " + found);
-                            }
-                        });
-                        notifyUnlockUserInput();
-                    }
+                worker = new Thread(() -> {
+                    notifyLockUserInput();
+                    final int found = doReplaceAll();
+                    SwingUtilities.invokeLater(() -> findDialog.setMessage("Replacements: " + found));
+                    notifyUnlockUserInput();
                 });
                 worker.setPriority(Thread.currentThread().getPriority() - 1);
                 worker.start();
@@ -867,7 +828,7 @@ public class SearchManager implements IDirectableViewer {
     }
 
     /**
-     * ask view to destroy itself
+     * ask tree to destroy itself
      */
     public void destroyView() throws CanceledException {
         // because the searchmanager is directed by all documents, don't want it to close when one document is closed
@@ -875,7 +836,7 @@ public class SearchManager implements IDirectableViewer {
     }
 
     /**
-     * ask view to prevent user input
+     * ask tree to prevent user input
      */
     public void lockUserInput() {
         isLocked = true;
@@ -896,7 +857,7 @@ public class SearchManager implements IDirectableViewer {
     }
 
     /**
-     * ask view to allow user input
+     * ask tree to allow user input
      */
     public void unlockUserInput() {
         if (isLocked) {
@@ -907,7 +868,7 @@ public class SearchManager implements IDirectableViewer {
     }
 
     /**
-     * ask view to update itself. This is method is wrapped into a runnable object
+     * ask tree to update itself. This is method is wrapped into a runnable object
      * and put in the swing event queue to avoid concurrent modifications.
      *
      * @param what what should be updated? Possible values: Director.ALL or Director.TITLE
@@ -956,7 +917,7 @@ public class SearchManager implements IDirectableViewer {
      * @param searchers
      * @param showReplace
      */
-    public void replaceSearchers(IDirector dir, ISearcher searchers[], boolean showReplace) {
+    public void replaceSearchers(IDirector dir, ISearcher[] searchers, boolean showReplace) {
         this.dir = dir;
         if (searchers != this.targets) {
             this.targets = searchers;
@@ -1145,11 +1106,9 @@ public class SearchManager implements IDirectableViewer {
      */
     private void notifyLockUserInput() {
         try {
-            SwingUtilities.invokeAndWait(new Runnable() {
-                public void run() {
-                    if (dir != null)
-                        dir.notifyLockInput();
-                }
+            SwingUtilities.invokeAndWait(() -> {
+                if (dir != null)
+                    dir.notifyLockInput();
             });
         } catch (Exception e) {
         }
@@ -1160,11 +1119,9 @@ public class SearchManager implements IDirectableViewer {
      */
     private void notifyUnlockUserInput() {
         try {
-            SwingUtilities.invokeAndWait(new Runnable() {
-                public void run() {
-                    if (dir != null)
-                        dir.notifyUnlockInput();
-                }
+            SwingUtilities.invokeAndWait(() -> {
+                if (dir != null)
+                    dir.notifyUnlockInput();
             });
         } catch (Exception e) {
         }
