@@ -1,7 +1,7 @@
 /*
- * DefaultGraphDrawer.java Copyright (C) 2019. Daniel H. Huson
+ * DefaultGraphDrawer.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.swing.graphview;
@@ -51,11 +52,11 @@ public class DefaultGraphDrawer implements IGraphDrawer {
 
     private INodeDrawer nodeDrawer;
 
-    private boolean radialLabels = false;
+    private final boolean radialLabels = false;
 
     private Node foundNode = null;
 
-    private int auxilaryParameter = 0; // not used
+    private final int auxilaryParameter = 0; // not used
 
     /**
      * constructor. Call only after graph and trans have been set for GraphView
@@ -116,7 +117,7 @@ public class DefaultGraphDrawer implements IGraphDrawer {
 // ensure that all nodes with labels have valid label rects
             for (Node v = graph.getFirstNode(); v != null; v = graph.getNextNode(v)) {
                 final NodeView nv = graphView.getNV(v);
-                if (nv.getLabel() != null)
+                if (nv.isLabelVisible() && nv.getLabel() != null)
                     nv.setLabelSize(BasicSwing.getStringSize(gc, graphView.getLabel(v), graphView.getFont(v))); // ensure label rect is set
             }
 
@@ -187,8 +188,9 @@ public class DefaultGraphDrawer implements IGraphDrawer {
 
             for (Node v = graph.getFirstNode(); v != null; v = graph.getNextNode(v)) {
                 if (!graphView.selectedNodes.contains(v)) {
-                    if (graphView.getNV(v).getLineWidth() != stroke.getLineWidth()) {
-                        stroke = new BasicStroke(graphView.getNV(v).getLineWidth());
+                    final NodeView nv = graphView.getNV(v);
+                    if (nv.getLineWidth() != stroke.getLineWidth()) {
+                        stroke = new BasicStroke(nv.getLineWidth());
                         gc.setStroke(stroke);
                     }
                     nodeDrawer.draw(v, false);
@@ -198,11 +200,11 @@ public class DefaultGraphDrawer implements IGraphDrawer {
             for (Node v = graph.getFirstNode(); v != null; v = graph.getNextNode(v)) {
                 if (!graphView.selectedNodes.contains(v)) {
                     final NodeView nv = graphView.getNV(v);
-                    if (graphView.getNV(v).getLineWidth() != stroke.getLineWidth()) {
+                    if (nv.getLineWidth() != stroke.getLineWidth()) {
                         stroke = new BasicStroke(graphView.getNV(v).getLineWidth());
                         gc.setStroke(stroke);
                     }
-                    if (labelOverlapAvoider.hasNoOverlapToPreviouslyDrawnLabels(v, nv)) {
+                    if (nv.isLabelVisible() && labelOverlapAvoider.hasNoOverlapToPreviouslyDrawnLabels(v, nv)) {
                         nodeDrawer.drawLabel(v, false);
                     }
                 }
