@@ -1,7 +1,7 @@
 /*
- * Magnifier.java Copyright (C) 2019. Daniel H. Huson
+ * Magnifier.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.swing.graphview;
@@ -424,7 +425,7 @@ public class Magnifier {
     }
 
 
-    class ArrowButton {
+    static class ArrowButton {
         final Polygon polygon;
 
         ArrowButton(int x, int y, boolean up) {
@@ -444,7 +445,7 @@ public class Magnifier {
         }
     }
 
-    class ZoomButton {
+    static class ZoomButton {
         final boolean up;
         final Rectangle rect;
 
