@@ -1,7 +1,7 @@
 /*
- * NodeView.java Copyright (C) 2019. Daniel H. Huson
+ * NodeView.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,13 +15,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 /**
  * Node visualization
  *
  * @version $Id: NodeView.java,v 1.82 2010-05-27 14:17:33 huson Exp $
- *
  * @author Daniel Huson
  */
 package jloda.swing.graphview;
@@ -42,8 +42,6 @@ final public class NodeView extends ViewBase implements Cloneable {
     private int height = 2;
     private int width = 2;
 
-    private final int GAPSIZE = 2; // gap between edge of node and start of edge
-
     private Color borderColor = null;
     private NodeShape nodeShape = NodeShape.Oval;
     //private byte imageLayout = NORTH;
@@ -69,7 +67,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     public static Writer descriptionWriter = null;
 
     /**
-     * Construct a node view.
+     * Construct a node tree.
      */
     public NodeView() {
         labelLayout = LAYOUT;
@@ -86,7 +84,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * copies the values of the source node view
+     * copies the values of the source node tree
      *
      * @param src
      */
@@ -98,6 +96,8 @@ final public class NodeView extends ViewBase implements Cloneable {
         width = src.width;
         nodeShape = src.nodeShape;
         fixedSize = src.getFixedSize();
+        borderColor = src.getBorderColor();
+        image = src.image;
     }
 
     /**
@@ -163,6 +163,8 @@ final public class NodeView extends ViewBase implements Cloneable {
                 p.y = apt.y;
             }
         } else {
+            // gap between edge of node and start of edge
+            int GAPSIZE = 2;
             int radius = Math.max(radius1, radius2) + GAPSIZE;
             double dist = apt.distance(bpt);
             if (dist == 0)
@@ -452,12 +454,14 @@ final public class NodeView extends ViewBase implements Cloneable {
                 gc.setFont(defaultFont);
             gc.setColor(ProgramProperties.SELECTION_COLOR);
             Shape shape = getLabelShape(trans);
-            gc.fill(shape);
-            gc.setColor(ProgramProperties.SELECTION_COLOR_DARKER);
-            final Stroke oldStroke = gc.getStroke();
-            gc.setStroke(NORMAL_STROKE);
-            gc.draw(shape);
-            gc.setStroke(oldStroke);
+            if (shape != null) {
+                gc.fill(shape);
+                gc.setColor(ProgramProperties.SELECTION_COLOR_DARKER);
+                final Stroke oldStroke = gc.getStroke();
+                gc.setStroke(NORMAL_STROKE);
+                gc.draw(shape);
+                gc.setStroke(oldStroke);
+            }
         }
     }
 
@@ -471,7 +475,6 @@ final public class NodeView extends ViewBase implements Cloneable {
         drawLabel(gc, trans, defaultFont, false);
     }
 
-
     /**
      * Draws the node's label and the image, if set
      *
@@ -482,11 +485,11 @@ final public class NodeView extends ViewBase implements Cloneable {
         if (location == null)
             return;
 
-        if (labelColor != null && label != null && label.length() > 0) {
+        if (labelVisible && labelColor != null && label != null && label.length() > 0) {
             //labelShape = null;
             //gc.setColor(Color.WHITE);
             //gc.fill(getLabelRect(trans));
-            if (labelBackgroundColor != null && labelVisible && enabled) {
+            if (labelBackgroundColor != null && enabled) {
                 gc.setColor(labelBackgroundColor);
                 gc.fill(getLabelShape(trans));
             }
@@ -513,9 +516,9 @@ final public class NodeView extends ViewBase implements Cloneable {
                     } else {
                         final float labelAngle = this.labelAngle + 0.00001f; // to ensure that labels all get same orientation in
 
-                            // save current transform:
-                            AffineTransform saveTransform = gc.getTransform();
-                            // a vertical phylogram view
+                        // save current transform:
+                        AffineTransform saveTransform = gc.getTransform();
+                        // a vertical phylogram tree
 
                             /*
                             AffineTransform localTransform =  gc.getTransform();
@@ -528,17 +531,17 @@ final public class NodeView extends ViewBase implements Cloneable {
                                 localTransform.rotate(labelAngle, apt.getX(), apt.getY());
                            gc.setTransform(localTransform);
                             */
-                            // todo: this doesn't work well as the angles aren't drawn correctly
+                        // todo: this doesn't work well as the angles aren't drawn correctly
 
-                            // rotate label to desired angle
-                            if (labelAngle >= 0.5 * Math.PI && labelAngle <= 1.5 * Math.PI) {
-                                apt = Geometry.translateByAngle(apt, labelAngle, getLabelSize().getWidth());
-                                gc.rotate(Geometry.moduloTwoPI(labelAngle - Math.PI), apt.getX(), apt.getY());
-                            } else {
-                                gc.rotate(labelAngle, apt.getX(), apt.getY());
-                            }
-                            gc.drawString(label, (int) apt.getX(), (int) apt.getY());
-                            gc.setTransform(saveTransform);
+                        // rotate label to desired angle
+                        if (labelAngle >= 0.5 * Math.PI && labelAngle <= 1.5 * Math.PI) {
+                            apt = Geometry.translateByAngle(apt, labelAngle, getLabelSize().getWidth());
+                            gc.rotate(Geometry.moduloTwoPI(labelAngle - Math.PI), apt.getX(), apt.getY());
+                        } else {
+                            gc.rotate(labelAngle, apt.getX(), apt.getY());
+                        }
+                        gc.drawString(label, (int) apt.getX(), (int) apt.getY());
+                        gc.setTransform(saveTransform);
                     }
                 }
             }
@@ -557,8 +560,7 @@ final public class NodeView extends ViewBase implements Cloneable {
             }
             try {
                 descriptionWriter.write(String.format("%s; x=%d y=%d w=%d h=%d\n", getLabel(), bounds.x, bounds.y, bounds.width, bounds.height));
-            } catch (IOException e) {
-                // silently ignore
+            } catch (IOException ignored) {
             }
         }
     }
@@ -758,7 +760,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * writes this node view
+     * writes this node tree
      *
      * @param w
      */
@@ -768,7 +770,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * gets a string representation of this node view, including coordinates
+     * gets a string representation of this node tree, including coordinates
      *
      * @return string representation
      */
@@ -777,7 +779,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * gets a string representation of this node view
+     * gets a string representation of this node tree
      *
      * @param withCoordinates show coordinates as well?
      * @return string representation
@@ -788,7 +790,7 @@ final public class NodeView extends ViewBase implements Cloneable {
 
 
     /**
-     * writes this node view
+     * writes this node tree
      *
      * @param w
      * @param previousNV if not null, only write those fields that differ from the values in previousNV
@@ -799,7 +801,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * gets a string representation of this node view
+     * gets a string representation of this node tree
      *
      * @param previousNV if not null, only write those fields that differ from the values in previousNV
      * @return string representation
@@ -809,7 +811,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * gets a string representation of this node view
+     * gets a string representation of this node tree
      *
      * @param previousNV if not null, only write those fields that differ from the values in previousNV
      * @return string representation
@@ -888,7 +890,7 @@ final public class NodeView extends ViewBase implements Cloneable {
     }
 
     /**
-     * reads a node view from a line
+     * reads a node tree from a line
      *
      * @param tokens
      * @param prevNV this must be !=null, for example can be set to graphView.defaultNodeView
