@@ -1,7 +1,7 @@
 /*
- * Transform.java Copyright (C) 2019. Daniel H. Huson
+ * Transform.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.swing.graphview;
@@ -202,8 +203,8 @@ public class Transform {
         angle = np.findIgnoreCase(tokens, "angle:", (float) angle);
         sinAngle = Math.sin(angle);
         cosAngle = Math.cos(angle);
-        scaleX = (double) np.findIgnoreCase(tokens, "scaleX:", (float) scaleX);
-        scaleY = (double) np.findIgnoreCase(tokens, "scaleY:", (float) scaleY);
+        scaleX = np.findIgnoreCase(tokens, "scaleX:", (float) scaleX);
+        scaleY = np.findIgnoreCase(tokens, "scaleY:", (float) scaleY);
         flipH = (np.findIgnoreCase(tokens, "flipH:", flipH ? 1 : 0) != 0);
         flipV = (np.findIgnoreCase(tokens, "flipV:", flipV ? 1 : 0) != 0);
         leftMargin = (int) np.findIgnoreCase(tokens, "leftMargin:", leftMargin);
