@@ -1,7 +1,7 @@
 /*
- * ArgsOptions.java Copyright (C) 2019. Daniel H. Huson
+ * ArgsOptions.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,15 +15,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.swing.util;
 
 import jloda.swing.message.MessageWindow;
-import jloda.util.Basic;
-import jloda.util.CanceledException;
-import jloda.util.ProgramProperties;
-import jloda.util.UsageException;
+import jloda.util.*;
 
 import javax.swing.*;
 import java.awt.*;
@@ -49,14 +47,16 @@ public class ArgsOptions {
     private final Set<String> shortKeys = new HashSet<>();
     private final Set<String> longKeys = new HashSet<>();
 
-    private final boolean usingInstall4j;
-
     private boolean alreadyHasOtherComment = false;
 
+    private boolean commandMandatory = false;
+
     private boolean doHelp = false;
 
     private static MessageWindow messageWindow = null;
 
+    private boolean optionFound = false;
+
     /**
      * constructor
      *
@@ -77,15 +77,6 @@ public class ArgsOptions {
      * @param description program description
      */
     public ArgsOptions(String[] args, Object main, String programName, String description) throws CanceledException {
-
-        if (args.length > 0 && args[0].equals("--install4j")) {
-            String[] tmp = new String[args.length - 1];
-            System.arraycopy(args, 1, tmp, 0, tmp.length);
-            args = tmp;
-            usingInstall4j = true;
-        } else
-            usingInstall4j = false;
-
         if (args.length > 0 && args[args.length - 1].equals("--argsGui")) {
             args = getDialogInput(args, args.length - 1);
         }
@@ -99,7 +90,7 @@ public class ArgsOptions {
         usage = new LinkedList<>();
 
         try {
-            doHelp = getOption("-h", "--help", "Show help", false, false);
+            doHelp = (args.length > 0 && args[0].equalsIgnoreCase("help")) || getOption("-h", "--help", "Show help", false, false);
             setVerbose(getOption("-v", "--verbose", "verbose", false) && !doHelp);
         } catch (UsageException e) {
         }
@@ -120,7 +111,7 @@ public class ArgsOptions {
     public String getUsage() {
         StringBuilder result = new StringBuilder();
         result.append("SYNOPSIS\n");
-        result.append("\t").append(programName).append(" [options]\n");
+        result.append("\t").append(programName).append(commandMandatory ? " command" : "").append(" [options]\n");
         result.append("DESCRIPTION\n");
         result.append("\t").append(getDescription()).append("\n");
 
@@ -163,8 +154,7 @@ public class ArgsOptions {
         else {      // replace by two or more spaces
             buf.append("  ");
             int top = Math.min(35, line.length());
-            for (int i = pos; i < top; i++)
-                buf.append(" ");
+            buf.append(" ".repeat(Math.max(0, top - pos)));
             pos++;
             while (pos < line.length()) {
                 buf.append(line.charAt(pos));
@@ -190,7 +180,7 @@ public class ArgsOptions {
         if (!doHelp) {
             if (version != null)
                 System.err.println("Version   " + version);
-            if (authors != null && license == null)
+            if (authors != null)
                 System.err.println("Author(s) " + authors);
             if (license != null)
                 System.err.println(license);
@@ -205,12 +195,12 @@ public class ArgsOptions {
                 throw new UsageException("Help");
         }
         if (arguments.size() > 0) {
-            String message = "Invalid, unknown or duplicate option:";
+            StringBuilder message = new StringBuilder("Invalid, unknown or duplicate option:");
             for (String arg : arguments) {
-                message += " " + arg;
+                message.append(" ").append(arg);
             }
-            message += "\n";
-            throw new UsageException(message);
+            message.append("\n");
+            throw new UsageException(message.toString());
         }
     }
 
@@ -267,7 +257,30 @@ public class ArgsOptions {
      * @throws UsageException
      */
     public String getCommand(String... legalValues) throws UsageException {
-        usage.add("\tcommand {" + Basic.toString(legalValues, "|") + "}");
+        final Command[] pairs = new Command[legalValues.length];
+        for (int i = 0; i < legalValues.length; i++)
+            pairs[i] = new Command(legalValues[i], null);
+        return getCommand(pairs);
+    }
+
+    /**
+     * gets a command (first value in arguments)
+     *
+     * @param pairs
+     * @return command
+     * @throws UsageException
+     */
+    public String getCommand(Command... pairs) throws UsageException {
+        final String[] legalValues = new String[pairs.length];
+        for (int i = 0; i < pairs.length; i++) {
+            legalValues[i] = pairs[i].get1();
+        }
+        usage.add(" Command " + Basic.toString(legalValues, " | "));
+
+        for (final Pair<String, String> pair : pairs) {
+            if (pair.get2() != null)
+                usage.add("\t" + pair.get1() + ": " + pair.get2());
+        }
 
         final String command;
         if (!isDoHelp()) {
@@ -279,6 +292,10 @@ public class ArgsOptions {
 
             if (verbose)
                 System.err.println("\tcommand: " + command);
+
+            if (command.equals("help"))
+                doHelp = true;
+
             return command;
         } else
             return "";
@@ -317,6 +334,7 @@ public class ArgsOptions {
             throw new UsageException("Option " + longKey + ": value=" + result + ": out of range: " + low + " - " + high);
         return result;
     }
+
     public int getOptionMandatory(String shortKey, String longKey, String description, Integer defaultValue) throws UsageException {
         return getOption(shortKey, longKey, description, defaultValue, true).intValue();
     }
@@ -375,37 +393,42 @@ public class ArgsOptions {
     }
 
     public String getOption(String shortKey, String longKey, String description, java.util.Collection<?> legalValues, String defaultValue) throws UsageException {
-        List<String> strings = new LinkedList<>();
-        for (Object v : legalValues)
-            strings.add(v.toString());
-        return getOption(shortKey, longKey, description, strings, defaultValue, false);
+        return getOption(shortKey, longKey, description, Arrays.asList(Basic.toStrings(legalValues)), defaultValue, false);
     }
 
     public String getOptionMandatory(String shortKey, String longKey, String description, Collection<?> legalValues, String defaultValue) throws UsageException {
-        List<String> strings = new LinkedList<>();
-        for (Object v : legalValues)
-            strings.add(v.toString());
-        return getOption(shortKey, longKey, description, strings, defaultValue, true);
+        return getOption(shortKey, longKey, description, Arrays.asList(Basic.toStrings(legalValues)), defaultValue, true);
     }
 
     public List<String> getOption(String shortKey, String longKey, String description, List<String> defaultValue) throws UsageException {
-        return getOption(shortKey, longKey, description, defaultValue, false);
+        return getOption(shortKey, longKey, description, null, defaultValue, false);
     }
 
     public List<String> getOptionMandatory(String shortKey, String longKey, String description, List<String> defaultValue) throws UsageException {
-        return getOption(shortKey, longKey, description, defaultValue, true);
+        return getOption(shortKey, longKey, description, null, defaultValue, true);
     }
 
     public String[] getOption(String shortKey, String longKey, String description, String[] defaultValue) throws UsageException {
-        List<String> result = getOption(shortKey, longKey, description, Arrays.asList(defaultValue), false);
-        return result.toArray(new String[result.size()]);
+        List<String> result = getOption(shortKey, longKey, description, null, Arrays.asList(defaultValue), false);
+        return result.toArray(new String[0]);
     }
 
     public String[] getOptionMandatory(String shortKey, String longKey, String description, String[] defaultValue) throws UsageException {
-        List<String> result = getOption(shortKey, longKey, description, Arrays.asList(defaultValue), true);
-        return result.toArray(new String[result.size()]);
+        List<String> result = getOption(shortKey, longKey, description, null, Arrays.asList(defaultValue), true);
+        return result.toArray(new String[0]);
     }
 
+    public String[] getOption(String shortKey, String longKey, String description, String[] legalValues, String[] defaultValue) throws UsageException {
+        List<String> result = getOption(shortKey, longKey, description, Arrays.asList(legalValues), Arrays.asList(defaultValue), false);
+        return result.toArray(new String[0]);
+    }
+
+    public String[] getOptionMandatory(String shortKey, String longKey, String description, String[] legalValues, String[] defaultValue) throws UsageException {
+        List<String> result = getOption(shortKey, longKey, description, Arrays.asList(legalValues), Arrays.asList(defaultValue), true);
+        return result.toArray(new String[0]);
+    }
+
+
     public Number getOption(String shortKey, String longKey, String description, Number defaultValue, boolean mandatory) throws UsageException {
         if (!shortKey.startsWith("-"))
             shortKey = "-" + shortKey;
@@ -425,7 +448,7 @@ public class ArgsOptions {
 
         Number result = defaultValue;
 
-        boolean found = false;
+        optionFound = false;
         Iterator<String> it = arguments.iterator();
         while (it.hasNext()) {
             String arg = it.next();
@@ -436,11 +459,11 @@ public class ArgsOptions {
                 }
                 result = getNumber(defaultValue, it.next());
                 it.remove();
-                found = true;
+                optionFound = true;
                 break;
             }
         }
-        if (!found) {
+        if (!optionFound) {
             if (mandatory && !doHelp)
                 throw new UsageException("Mandatory option '" + longKey + "' not specified");
         }
@@ -450,6 +473,9 @@ public class ArgsOptions {
     }
 
     private boolean getOption(String shortKey, String longKey, String description, boolean defaultValue, boolean mandatory) throws UsageException {
+        if (shortKey.equals("+g"))
+            shortKey = "-g"; // for backward compatibility
+
         boolean hide = false;
         if (shortKey.startsWith("!")) {
             hide = true;
@@ -474,7 +500,7 @@ public class ArgsOptions {
             usage.add("\t" + shortKey + ", " + longKey + ": " + description + ". " + (mandatory ? "Mandatory option." : "Default value: " + defaultValue + "."));
 
         boolean result = false;
-        boolean found = false;
+        optionFound = false;
         Iterator<String> it = arguments.iterator();
         while (it.hasNext()) {
             String arg = it.next();
@@ -482,22 +508,22 @@ public class ArgsOptions {
                 it.remove();
                 if (!it.hasNext()) {
                     result = !defaultValue;
-                    found = true;
+                    optionFound = true;
                     break;
                 }
                 String value = it.next();
                 if (value.length() > 0 && (value.startsWith("-") || value.startsWith("+"))) {
                     result = !defaultValue;
-                    found = true;
+                    optionFound = true;
                     break;
                 }
                 it.remove();
                 result = Boolean.parseBoolean(value);
-                found = true;
+                optionFound = true;
                 break;
             }
         }
-        if (!found) {
+        if (!optionFound) {
             if (mandatory && !doHelp)
                 throw new UsageException("Mandatory option '" + longKey + "' not specified");
             else
@@ -528,7 +554,7 @@ public class ArgsOptions {
         else
             longKeys.add(longKey);
 
-        String defaultValueString = (defaultValue.length() == 0 ? "" : "Default value: " + defaultValue + ".");
+        String defaultValueString = (defaultValue.length() == 0 ? "" : "Default value: " + defaultValue);
 
         if (!hide)
             usage.add("\t" + shortKey + ", " + longKey + " [string]: " + description + ". " + (mandatory ? "Mandatory option." : defaultValueString)
@@ -536,7 +562,7 @@ public class ArgsOptions {
 
         String result = defaultValue;
 
-        boolean found = false;
+        optionFound = false;
         final Iterator<String> it = arguments.iterator();
         while (it.hasNext()) {
             String arg = it.next();
@@ -547,14 +573,14 @@ public class ArgsOptions {
                 }
                 result = it.next();
                 it.remove();
-                found = true;
+                optionFound = true;
                 if (legalValues != null && !legalValues.contains(result))
                     throw new UsageException("Illegal value for option " + longKey + ": " + result + ", legal values: " + Basic.toString(legalValues, ", "));
 
                 break;
             }
         }
-        if (!found) {
+        if (!optionFound) {
             if (mandatory && !doHelp)
                 throw new UsageException("Mandatory option '" + longKey + "' not specified" + (legalValues != null ? ", legal values: " + Basic.toString(legalValues, ", ") : "."));
         }
@@ -563,7 +589,7 @@ public class ArgsOptions {
         return result;
     }
 
-    private List<String> getOption(String shortKey, String longKey, String description, List<String> defaultValue, boolean mandatory) throws UsageException {
+    private List<String> getOption(String shortKey, String longKey, String description, Collection<String> legalValues, List<String> defaultValue, boolean mandatory) throws UsageException {
         boolean hide = false;
         if (shortKey.startsWith("!")) {
             hide = true;
@@ -583,20 +609,26 @@ public class ArgsOptions {
         else
             longKeys.add(longKey);
 
-        String defaultValueString = (defaultValue.size() == 0 ? "" : "Default value(s): " + Basic.toString(defaultValue, " ") + ".");
+        String defaultValueString = (defaultValue.size() == 0 ? "" : "Default value(s): '" + Basic.toString(defaultValue, "' '")+"'");
 
-        if (!hide)
-            usage.add("\t" + shortKey + ", " + longKey + " [string(s)]: " + description + ". " + (mandatory ? "Mandatory option." : defaultValueString));
+        if (!hide) {
+            if (mandatory)
+                usage.add("\t" + shortKey + ", " + longKey + " [string(s)]: " + description + ". Mandatory option" + (legalValues != null ? " legal values: " + Basic.toString(legalValues, ", ") : "") + ".");
+            else
+                usage.add("\t" + shortKey + ", " + longKey + " [string(s)]: " + description + ". " + defaultValueString + (legalValues != null ? " legal values: " + Basic.toString(legalValues, ", ") + "." : defaultValueString.length() > 0 ? "." : ""));
 
+        }
         List<String> result = new LinkedList<>();
         boolean inArguments = false; // once in arguments, will continue until argument starts with -
 
+        optionFound = false;
         Iterator<String> it = arguments.iterator();
         while (it.hasNext()) {
             String arg = it.next();
             if (arg.equals(shortKey) || arg.equals(longKey)) {
                 it.remove();
                 inArguments = true;
+                optionFound = true;
             }
             if (inArguments) {
                 boolean done = false;
@@ -607,6 +639,9 @@ public class ArgsOptions {
                         break;
                     }
                     it.remove();
+                    if (legalValues != null && !legalValues.contains(value))
+                        throw new UsageException("Illegal value for option " + longKey + ": " + value + ", legal values: " + Basic.toString(legalValues, ", "));
+
                     result.add(value);
                 }
                 if (done)
@@ -698,7 +733,21 @@ public class ArgsOptions {
         return messageWindow != null && messageWindow.isVisible();
     }
 
-    public boolean isUsingInstall4j() {
-        return usingInstall4j;
+    public boolean optionWasExplicitlySet() {
+        return optionFound;
+    }
+
+    public boolean isCommandMandatory() {
+        return commandMandatory;
+    }
+
+    public void setCommandMandatory(boolean commandMandatory) {
+        this.commandMandatory = commandMandatory;
+    }
+
+    public static class Command extends Pair<String, String> {
+        public Command(String name, String description) {
+            super(name, description);
+        }
     }
 }
