@@ -1,7 +1,7 @@
 /*
- * CanceledException.java Copyright (C) 2019. Daniel H. Huson
+ * CanceledException.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,17 +15,20 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.util;
 
+import java.io.IOException;
+
 /**
  * User canceled exception
  *
  * @author huson
- *         Date: 04-Dec-2003
+ * Date: 04-Dec-2003
  */
-public class CanceledException extends Exception {
+public class CanceledException extends IOException {
     public CanceledException() {
         super();
     }
