@@ -1,7 +1,7 @@
 /*
- * IFastAIterator.java Copyright (C) 2019. Daniel H. Huson
+ * IFastAIterator.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,10 +15,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.util;
 
+import java.util.stream.Stream;
+
 /**
  * header for fastA and fastQAsFastA iterators
  * Daniel Huson, 3.2014
@@ -37,4 +40,11 @@ public interface IFastAIterator extends ICloseableIterator<Pair<String, String>>
      * @return
      */
     long getNumberOfBytes();
+
+    /**
+     * get the stream
+     *
+     * @return stream
+     */
+    Stream<Pair<String, String>> stream();
 }
