@@ -1,7 +1,7 @@
 /*
- * NexusStreamParser.java Copyright (C) 2019. Daniel H. Huson
+ * NexusStreamParser.java Copyright (C) 2020. Daniel H. Huson
  *
- *  (Some files contain contributions from other authors, who are then mentioned separately.)
+ * (Some code written by other authors, as named in code.)
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 package jloda.util.parse;
@@ -452,13 +453,13 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
     public String getTokensFileNamePunctuation(String first, String last) throws IOExceptionWithLineNumber {
         pushPunctuationCharacters(SEMICOLON_PUNCTUATION);
 
-        String result = "";
+        StringBuilder result = new StringBuilder();
         try {
             if (first != null)
                 matchIgnoreCase(first);
             nextToken();
             while (!toString().equals(last)) {
-                result += " " + toString();
+                result.append(" ").append(toString());
                 if (ttype == TT_EOF)
                     throw new IOExceptionWithLineNumber("'" + last + "' expected, got EOF", lineno());
                 nextToken();
@@ -468,9 +469,9 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         } finally {
             popPunctuationCharacters();
         }
-        if (result.equals(""))
+        if (result.toString().equals(""))
             return null;
-        return result;
+        return result.toString();
     }
 
     /**
@@ -532,11 +533,11 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
      * and 'last'
      */
     public String getTokensStringLowerCase(String last) throws IOExceptionWithLineNumber {
-        String result = "";
+        StringBuilder result = new StringBuilder();
         try {
             nextToken();
             while (!toString().equalsIgnoreCase(last)) {
-                result += " " + toString().toLowerCase();
+                result.append(" ").append(toString().toLowerCase());
                 if (ttype == TT_EOF)
                     throw new IOExceptionWithLineNumber("'" + last + "' expected, got EOF", lineno());
                 nextToken();
@@ -544,9 +545,9 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         } catch (IOException ex) {
             throw new IOExceptionWithLineNumber(lineno(), ex);
         }
-        if (result.equals(""))
+        if (result.toString().equals(""))
             return null;
-        return result;
+        return result.toString();
     }
 
 
@@ -561,11 +562,11 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
      * and 'last'
      */
     public String getTokensStringRespectCase(String last) throws IOExceptionWithLineNumber {
-        String result = "";
+        StringBuilder result = new StringBuilder();
         try {
             nextToken();
             while (!toString().equals(last)) {
-                result += " " + toString();
+                result.append(" ").append(toString());
                 if (ttype == TT_EOF)
                     throw new IOExceptionWithLineNumber("'" + last + "' expected, got EOF", lineno());
                 nextToken();
@@ -573,9 +574,9 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         } catch (IOException ex) {
             throw new IOExceptionWithLineNumber(lineno(), ex);
         }
-        if (result.equals(""))
+        if (result.toString().equals(""))
             return null;
-        return result.trim();
+        return result.toString().trim();
     }
 
     /**
@@ -684,7 +685,7 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         boolean found = false;
         // The following line seems to be a bug - have replaced it
         //String result = defaultValue;
-        String result = "";
+        StringBuilder result = new StringBuilder();
 
         NexusStreamParser s =
                 new NexusStreamParser(new StringReader(List2String(tokens)));
@@ -701,9 +702,9 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
 
                         if (word.equalsIgnoreCase(rightDelimiter))
                             break;
-                        if (!result.equals(""))
-                            result += " ";
-                        result += word;
+                        if (!result.toString().equals(""))
+                            result.append(" ");
+                        result.append(word);
                     }
                 } else {
                     if (s.nextToken() != NexusStreamParser.TT_EOF)
@@ -713,9 +714,9 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         } catch (IOException ex) {
             throw new IOExceptionWithLineNumber(lineno(), ex);
         }
-        if (result.equals(""))
-            result = defaultValue;
-        return result;
+        if (result.toString().equals(""))
+            result = new StringBuilder(defaultValue);
+        return result.toString();
     }
 
     /**
@@ -789,7 +790,7 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
                         throw new IOExceptionWithLineNumber(token + " '" + result + "': char expected", lineno());
                     result = str.charAt(0);
                     found = true;
-                    if (legalValues != null && legalValues.indexOf((int) result) == -1)
+                    if (legalValues != null && legalValues.indexOf(result) == -1)
                         throw new IOExceptionWithLineNumber(token + " '" + result + "': illegal value", lineno());
                 } else {
                     if (s.nextToken() != NexusStreamParser.TT_EOF)
@@ -895,8 +896,8 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
     /**
      * Searches for an occurrence of a token value, where value is a color
      *
-     * @param tokens the list of tokens
-     * @param token    the token to look for
+     * @param tokens       the list of tokens
+     * @param token        the token to look for
      * @param defaultValue the return value, if token not found
      * @return the value
      */
@@ -999,7 +1000,7 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         pushPunctuationCharacters(NEGATIVE_INTEGER_PUNCTUATION);
         try {
             nextToken();
-            nval = Integer.valueOf(sval);
+            nval = Integer.parseInt(sval);
         } catch (Exception ex) {
             popPunctuationCharacters();
             throw new IOExceptionWithLineNumber("INTEGER expected, got: '" + sval + "'", lineno());
@@ -1038,7 +1039,7 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         pushPunctuationCharacters(NEGATIVE_INTEGER_PUNCTUATION);
         try {
             nextToken();
-            nval = Long.valueOf(sval);
+            nval = Long.parseLong(sval);
         } catch (Exception ex) {
             popPunctuationCharacters();
             throw new IOExceptionWithLineNumber("LONG expected, got: '" + sval + "'", lineno());
@@ -1056,7 +1057,7 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         pushPunctuationCharacters(LABEL_PUNCTUATION);
         try {
             nextToken();
-            nval = Double.valueOf(sval);
+            nval = Double.parseDouble(sval);
         } catch (Exception ex) {
             popPunctuationCharacters();
             throw new IOExceptionWithLineNumber("DOUBLE expected, got: '" + sval + "'", lineno());
@@ -1087,9 +1088,9 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         double result = getDouble();
 
         if (result < low || result > high) {
-            if (low > Double.MIN_VALUE && high == Double.MAX_VALUE)
+            if (low > Double.NEGATIVE_INFINITY && high == Double.POSITIVE_INFINITY)
                 throw new IOExceptionWithLineNumber("value " + result + " smaller than minimum: " + low, lineno());
-            else if (low == Double.MIN_VALUE && high < Double.MAX_VALUE)
+            else if (low == Double.NEGATIVE_INFINITY && high < Double.POSITIVE_INFINITY)
                 throw new IOExceptionWithLineNumber("value " + result + " larger than maximum: " + high, lineno());
             else
                 throw new IOExceptionWithLineNumber("value " + result + " out of range: " + low + " - " + high, lineno());
@@ -1187,16 +1188,16 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
      */
     public String convertToBlock(String firstSourceLabel, String lastSourceLabel, String blockName) throws Exception {
         pushPunctuationCharacters(SEMICOLON_PUNCTUATION);
-        String str = "begin " + blockName + ";";
+        StringBuilder str = new StringBuilder("begin " + blockName + ";");
         try {
             List<String> tokens = getTokensRespectCase(firstSourceLabel, lastSourceLabel);
-            for (String token : tokens) str += " " + token;
+            for (String token : tokens) str.append(" ").append(token);
 
-            str += ";end;";
+            str.append(";end;");
         } finally {
             popPunctuationCharacters();
         }
-        return str;
+        return str.toString();
     }
 
     /**
@@ -1649,6 +1650,10 @@ public class NexusStreamParser extends NexusStreamTokenizer implements Closeable
         }
         return blockName;
     }
+
+    public boolean peekInteger() {
+        return Basic.isInteger(peekNextWord());
+    }
 }
 
 // EOF
